Learn R Programming

PUGMM (version 0.1.2)

pugmm_available_models: PUGMM Model Names

Description

Description of the model names used in the PUGMM package.

Usage

pugmm_available_models()

Arguments

Value

Available models in PUGMM, i.e., the thirteen extended ultrametric covariance structures of PUGMM.

Details

The PUGMM model names in the PUGMM package are characterized by four letters:

  • First letter: it refers to the variable-group membership matrix \(V\), which can be equal (E) or free to vary (F) across components.

  • Second, third, fourth letters: they refer to the matrices of the group variances \(\Sigma_{V}\), the within-group covariances \(\Sigma_{W}\) and the between-group covariances \(\Sigma_{B}\), respectively, by indicating if they are unique (U, i.e., equal within and across components), isotropic (I, i.e., equal within components), equal (E, i.e., equal across components) or free to vary across components (F).

References

Cavicchia, C., Vichi, M., Zaccaria, G. (2024) Parsimonious ultrametric Gaussian mixture models. Statistics and Computing, 34, 108.

See Also

pugmm()

Examples

Run this code
pugmm_available_models()

Run the code above in your browser using DataLab